Class: Google::Apis::WorkflowsV1::OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::WorkflowsV1::OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workflows_v1/classes.rb,
lib/google/apis/workflows_v1/representations.rb,
lib/google/apis/workflows_v1/representations.rb
Overview
Represents the metadata of the long-running operation.
Instance Attribute Summary collapse
-
#api_version ⇒ String
API version used to start the operation.
-
#create_time ⇒ String
The time the operation was created.
-
#end_time ⇒ String
The time the operation finished running.
-
#target ⇒ String
Server-defined resource path for the target of the operation.
-
#verb ⇒ String
Name of the verb executed by the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadata
constructor
A new instance of OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadata
Returns a new instance of OperationMetadata.
296 297 298 |
# File 'lib/google/apis/workflows_v1/classes.rb', line 296 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
API version used to start the operation.
Corresponds to the JSON property apiVersion
274 275 276 |
# File 'lib/google/apis/workflows_v1/classes.rb', line 274 def api_version @api_version end |
#create_time ⇒ String
The time the operation was created.
Corresponds to the JSON property createTime
279 280 281 |
# File 'lib/google/apis/workflows_v1/classes.rb', line 279 def create_time @create_time end |
#end_time ⇒ String
The time the operation finished running.
Corresponds to the JSON property endTime
284 285 286 |
# File 'lib/google/apis/workflows_v1/classes.rb', line 284 def end_time @end_time end |
#target ⇒ String
Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
289 290 291 |
# File 'lib/google/apis/workflows_v1/classes.rb', line 289 def target @target end |
#verb ⇒ String
Name of the verb executed by the operation.
Corresponds to the JSON property verb
294 295 296 |
# File 'lib/google/apis/workflows_v1/classes.rb', line 294 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
301 302 303 304 305 306 307 |
# File 'lib/google/apis/workflows_v1/classes.rb', line 301 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |