Class: Google::Apis::WorkflowsV1::Workflow

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workflows_v1/classes.rb,
lib/google/apis/workflows_v1/representations.rb,
lib/google/apis/workflows_v1/representations.rb

Overview

Workflow program to be executed by Workflows.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Workflow

Returns a new instance of Workflow.



509
510
511
# File 'lib/google/apis/workflows_v1/classes.rb', line 509

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_kms_keysArray<String>

Output only. A list of all KMS crypto keys used to encrypt or decrypt the data associated with the workflow. Corresponds to the JSON property allKmsKeys

Returns:

  • (Array<String>)


382
383
384
# File 'lib/google/apis/workflows_v1/classes.rb', line 382

def all_kms_keys
  @all_kms_keys
end

#all_kms_keys_versionsArray<String>

Output only. A list of all KMS crypto key versions used to encrypt or decrypt the data associated with the workflow. Corresponds to the JSON property allKmsKeysVersions

Returns:

  • (Array<String>)


388
389
390
# File 'lib/google/apis/workflows_v1/classes.rb', line 388

def all_kms_keys_versions
  @all_kms_keys_versions
end

#call_log_levelString

Optional. Describes the level of platform logging to apply to calls and call responses during executions of this workflow. If both the workflow and the execution specify a logging level, the execution level takes precedence. Corresponds to the JSON property callLogLevel

Returns:

  • (String)


395
396
397
# File 'lib/google/apis/workflows_v1/classes.rb', line 395

def call_log_level
  @call_log_level
end

#create_timeString

Output only. The timestamp for when the workflow was created. This is a workflow-wide field and is not tied to a specific revision. Corresponds to the JSON property createTime

Returns:

  • (String)


401
402
403
# File 'lib/google/apis/workflows_v1/classes.rb', line 401

def create_time
  @create_time
end

#crypto_key_nameString

Optional. The resource name of a KMS crypto key used to encrypt or decrypt the data associated with the workflow. Format: projects/project/locations/ location/keyRings/keyRing/cryptoKeys/cryptoKey Using - as a wildcard for the project or not providing one at all will infer the project from the account. If not provided, data associated with the workflow will not be CMEK-encrypted. Corresponds to the JSON property cryptoKeyName

Returns:

  • (String)


411
412
413
# File 'lib/google/apis/workflows_v1/classes.rb', line 411

def crypto_key_name
  @crypto_key_name
end

#crypto_key_versionString

Output only. The resource name of a KMS crypto key version used to encrypt or decrypt the data associated with the workflow. Format: projects/project/ locations/location/keyRings/keyRing/cryptoKeys/cryptoKey/ cryptoKeyVersions/cryptoKeyVersion Corresponds to the JSON property cryptoKeyVersion

Returns:

  • (String)


419
420
421
# File 'lib/google/apis/workflows_v1/classes.rb', line 419

def crypto_key_version
  @crypto_key_version
end

#descriptionString

Description of the workflow provided by the user. Must be at most 1000 Unicode characters long. This is a workflow-wide field and is not tied to a specific revision. Corresponds to the JSON property description

Returns:

  • (String)


426
427
428
# File 'lib/google/apis/workflows_v1/classes.rb', line 426

def description
  @description
end

#execution_history_levelString

Optional. Describes the execution history level to apply to this workflow. Corresponds to the JSON property executionHistoryLevel

Returns:

  • (String)


431
432
433
# File 'lib/google/apis/workflows_v1/classes.rb', line 431

def execution_history_level
  @execution_history_level
end

#labelsHash<String,String>

Labels associated with this workflow. Labels can contain at most 64 entries. Keys and values can be no longer than 63 characters and can only contain lowercase letters, numeric characters, underscores, and dashes. Label keys must start with a letter. International characters are allowed. This is a workflow-wide field and is not tied to a specific revision. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


440
441
442
# File 'lib/google/apis/workflows_v1/classes.rb', line 440

def labels
  @labels
end

#nameString

The resource name of the workflow. Format: projects/project/locations/ location/workflows/workflow. This is a workflow-wide field and is not tied to a specific revision. Corresponds to the JSON property name

Returns:

  • (String)


447
448
449
# File 'lib/google/apis/workflows_v1/classes.rb', line 447

def name
  @name
end

#revision_create_timeString

Output only. The timestamp for the latest revision of the workflow's creation. Corresponds to the JSON property revisionCreateTime

Returns:

  • (String)


452
453
454
# File 'lib/google/apis/workflows_v1/classes.rb', line 452

def revision_create_time
  @revision_create_time
end

#revision_idString

Output only. The revision of the workflow. A new revision of a workflow is created as a result of updating the following properties of a workflow: - Service account - Workflow code to be executed The format is "000001-a4d", where the first six characters define the zero-padded revision ordinal number. They are followed by a hyphen and three hexadecimal random characters. Corresponds to the JSON property revisionId

Returns:

  • (String)


461
462
463
# File 'lib/google/apis/workflows_v1/classes.rb', line 461

def revision_id
  @revision_id
end

#service_accountString

The service account associated with the latest workflow version. This service account represents the identity of the workflow and determines what permissions the workflow has. Format: projects/project/serviceAccounts/ account or account Using - as a wildcard for the project or not providing one at all will infer the project from the account. The account value can be the email address or the unique_id of the service account. If not provided, workflow will use the project's default service account. Modifying this field for an existing workflow results in a new workflow revision. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


474
475
476
# File 'lib/google/apis/workflows_v1/classes.rb', line 474

def 
  @service_account
end

#source_contentsString

Workflow code to be executed. The size limit is 128KB. Corresponds to the JSON property sourceContents

Returns:

  • (String)


479
480
481
# File 'lib/google/apis/workflows_v1/classes.rb', line 479

def source_contents
  @source_contents
end

#stateString

Output only. State of the workflow deployment. Corresponds to the JSON property state

Returns:

  • (String)


484
485
486
# File 'lib/google/apis/workflows_v1/classes.rb', line 484

def state
  @state
end

#state_errorGoogle::Apis::WorkflowsV1::StateError

Describes an error related to the current state of the workflow. Corresponds to the JSON property stateError



489
490
491
# File 'lib/google/apis/workflows_v1/classes.rb', line 489

def state_error
  @state_error
end

#tagsHash<String,String>

Optional. Input only. Immutable. Tags associated with this workflow. Corresponds to the JSON property tags

Returns:

  • (Hash<String,String>)


494
495
496
# File 'lib/google/apis/workflows_v1/classes.rb', line 494

def tags
  @tags
end

#update_timeString

Output only. The timestamp for when the workflow was last updated. This is a workflow-wide field and is not tied to a specific revision. Corresponds to the JSON property updateTime

Returns:

  • (String)


500
501
502
# File 'lib/google/apis/workflows_v1/classes.rb', line 500

def update_time
  @update_time
end

#user_env_varsHash<String,String>

Optional. User-defined environment variables associated with this workflow revision. This map has a maximum length of 20. Each string can take up to 4KiB. Keys cannot be empty strings and cannot start with "GOOGLE" or "WORKFLOWS". Corresponds to the JSON property userEnvVars

Returns:

  • (Hash<String,String>)


507
508
509
# File 'lib/google/apis/workflows_v1/classes.rb', line 507

def user_env_vars
  @user_env_vars
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
# File 'lib/google/apis/workflows_v1/classes.rb', line 514

def update!(**args)
  @all_kms_keys = args[:all_kms_keys] if args.key?(:all_kms_keys)
  @all_kms_keys_versions = args[:all_kms_keys_versions] if args.key?(:all_kms_keys_versions)
  @call_log_level = args[:call_log_level] if args.key?(:call_log_level)
  @create_time = args[:create_time] if args.key?(:create_time)
  @crypto_key_name = args[:crypto_key_name] if args.key?(:crypto_key_name)
  @crypto_key_version = args[:crypto_key_version] if args.key?(:crypto_key_version)
  @description = args[:description] if args.key?(:description)
  @execution_history_level = args[:execution_history_level] if args.key?(:execution_history_level)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @revision_create_time = args[:revision_create_time] if args.key?(:revision_create_time)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
  @service_account = args[:service_account] if args.key?(:service_account)
  @source_contents = args[:source_contents] if args.key?(:source_contents)
  @state = args[:state] if args.key?(:state)
  @state_error = args[:state_error] if args.key?(:state_error)
  @tags = args[:tags] if args.key?(:tags)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user_env_vars = args[:user_env_vars] if args.key?(:user_env_vars)
end